==> qtjambi-quick-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiQuick/QSGRenderNode_shell.h <==
#ifndef QSGRENDERNODE_SHELL_H
#define QSGRENDERNODE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQuick/qsgrendernode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qrect.h>
#include <QtGui/6.6.0/QtGui/rhi/qrhi.h>
#include <QtGui/qmatrix4x4.h>
#include <QtQuick/qsgnode.h>
#include <QtJambi/RegistryAPI>


class QSGRenderNode_shell : public QSGRenderNode, public QtJambiShellInterface
{
public:
    QSGRenderNode_shell();
    ~QSGRenderNode_shell() override;

    QSGRenderNode::StateFlags changedStates() const override;
    QSGRenderNode::RenderingFlags flags() const override;
    bool isSubtreeBlocked() const override;
    void prepare() override;
    void preprocess() override;
    QRectF rect() const override;
    void releaseResources() override;
    void render(const QSGRenderNode::RenderState* state0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSGRenderNode_access : public QSGRenderNode
{
    jint __qt_changedStates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_renderingFlags(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_prepare(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_rect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_releaseResources(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_render_const_QSGRenderNode_RenderState_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID state0);
};

#endif // QSGRENDERNODE_SHELL_H

==> qtjambi-quick-debuginfo-linux-x64-6.6.3.jar: sources/QtJambiQuick/QSGRenderNode_shell.h <==
#ifndef QSGRENDERNODE_SHELL_H
#define QSGRENDERNODE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qsgrendernode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qrect.h>
#include <QtGui/qmatrix4x4.h>
#include <QtGui/rhi/qrhi.h>
#include <QtQuick/qsgnode.h>
#include <QtJambi/RegistryAPI>


class QSGRenderNode_shell : public QSGRenderNode, public QtJambiShellInterface
{
public:
    QSGRenderNode_shell();
    ~QSGRenderNode_shell() override;

    QSGRenderNode::StateFlags changedStates() const override;
    QSGRenderNode::RenderingFlags flags() const override;
    bool isSubtreeBlocked() const override;
    void prepare() override;
    void preprocess() override;
    QRectF rect() const override;
    void releaseResources() override;
    void render(const QSGRenderNode::RenderState* state0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSGRenderNode_access : public QSGRenderNode
{
    jint __qt_changedStates_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_renderingFlags_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_prepare(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_rect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_releaseResources(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_render_const_QSGRenderNode_RenderState_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID state0);
};

#endif // QSGRENDERNODE_SHELL_H
